.. _refman:

================
Reference Manual
================

Module, class, and function reference

HydraTK
=======

.. toctree::
   :maxdepth: 1

   refman/hydra/core
   refman/hydra/lib

Extensions   
==========

.. toctree::
   :maxdepth: 1

   refman/exts/benchmark
   refman/exts/datagen
   refman/exts/testenv
   refman/exts/trackapps
   refman/exts/yoda
   
Libraries
=========

.. toctree::
   :maxdepth: 1

   refman/libs/network   